public class StickDrag extends TrigDrag
{
  WhiteLabel  angleLabel;
  boolean     showAngle;
  
  /*****************************************************************
    Return information about applet for use in an About... box
  ******************************************************************/
  public String getAppletInfo()
  {
    return "Stick Drag Applet \u00a9 1996-2005 J. David Eisenberg.";
  }
  
  /*****************************************************************
    Return information about parameters for browsers and
    applet viewers.
  ******************************************************************/
  public String[][] getParameterInfo()
  {
    String[][] info = 
    {
      // name       type    description
      { "length",     "integer",  "length of hypotenuse in pixels (50)" },
      { "maxAngle",   "integer",  "maximum angle of hypotenuse from 0 to 360 (90) " },
      { "drawShadow",   "boolean",  "draw a shadow under the stick? (TRUE)" },
      { "drawTriangle", "boolean",  "draw the full triangle around the stick? (FALSE)" },
      { "showAngle",    "boolean",  "show a label with current angle? (FALSE)" }
    };
    return info;
  }

function init(params) {
  var angle;
  var len;
  var drawShadow;
  var drawTriangle;
  var showAngle;
  var ctx;
  
  /*******************************************************************
    Get hypotenuse length. If invalid, use 50 pixels as a default
  *********************************************************************/
  len = getParameter(params.length, 50);
    
  if (len <= 0 || len > 200) { len = 50; }
    
  /*******************************************************************
    Get maximum angle. If out of range, use 90 degrees as a default
  *********************************************************************/
  angle = getIntegerParameter( "maxAngle", 90 );

  if ((angle < 0) || (angle > 360))
  {
    angle = 90;
  }

  /*******************************************************************
    Do we want to draw a shadow on ground and wall? (default yes)
  *********************************************************************/
  drawShadow = getParameter(params.drawShadow, true );

  /*******************************************************************
    Do we want to draw the triangle? (default no)
  *********************************************************************/
  drawTriangle = getParameter(params.drawTriangle, false);

  /*******************************************************************
    Do we want to show the numeric angle? (default yes)
  *********************************************************************/
  showAngle = getParameter(params.showAngle, true);

  content = document.getElementById(params.canvasId).getContext('2d');
  content.setBackground( Color.white );

  content.setLayout( new FlowLayout( FlowLayout.CENTER ) );
  setTriangle(
    new DraggableStick( len, angle, drawShadow, drawTriangle )
  );

  content.add( getTriangle( ) );
  
  getTriangle().addMouseListener( this );
  getTriangle().addMouseMotionListener( this );
  
  if (showAngle)
  {
    angleLabel = new WhiteLabel();
  
    content.add( angleLabel );
    angleLabel.setHorizontalAlignment( JLabel.CENTER );
      
    updateLabels();
  }
}


  protected synchronized void updateLabels()
  {
    int   angle;
    
    if (showAngle)
    {
      angle = getTriangle().getCurrentAngle();
      angleLabel.setText( "The stick's angle is " + angle + "\u00b0.");
    }
  }
}
