/*******************************************************************************
    SpiralDraw
    
        Get entries for input of formulas of the form:
        
           multiplier * sin( coeff * angle + offset ) or
           multiplier * cos( coeff * angle + offset )
        
        and a "spiral-draw" which, given that T stands for angle theta
        
            f(T) = a sin(bT + c)    ... you can replace sin with cos, of course
            g(T) = d sin(eT + f)
            
        plots either an "Polar diagram"
            
            r = f(T) + g(T)
            
        or a Lissajous figure:
        
            x = f(T): y = g(T)
            
        
        Copyright © 2017 J. David Eisenberg
*********************************************************************************/

var SpiralDraw = {
    canvas: null,
    ctx: null,
    length: 80,       // length of hypotenuse in pixels
    angle: -1,        // current angle of hypotenuse, measured in degrees
    prevAngle: -1,    // previous angle (-1 = Nothing drawn yet)
    xPrev: 0,         // previous value of X (for drawing lines)
    yPrev: 0,         // previous value of Y (for drawing lines)
    xPos: 0,          // current value of X
    yPos: 0,          // current value of Y
    xBase: 85,        // x coordinate of center
    yBase: 85,        // y coordinate of center
    scaleMax: 0,      // what is the maximum x or y value?
    running: null,    // 
    
    init: function(canvasId, settings) {
        Object.assign(this, settings);
        this.canvas = document.getElementById(canvasId);
        this.ctx = this.canvas.getContext("2d");
    },
    
    draw: function() {
        var ctx = this.ctx;
        ctx.fillStyle = "#fff";
        ctx.fillRect(0, 0, this.canvas.width, this.canvas.height);
        ctx.strokeStyle = "gray";
        drawLine(ctx, this.xBase - this.length, this.yBase, this.xBase + this.length, this.yBase);
        drawLine(ctx, this.xBase, this.yBase - this.length, this.xBase, this.yBase + this.length);
    },
    
    plot: function() {
        if (this.prevAngle != -1) {
            this.ctx.strokeStyle="magenta";
            drawLine(this.ctx, this.xPrev, this.yPrev, this.xPos, this.yPos);
        }
        this.xPrev = this.xPos;
        this.yPrev = this.yPos;
        this.prevAngle = this.angle;
    },
    
    polar: function(angle, f1, f2) {
        var r = f1 + f2;
        this.xPos = this.xBase + (r * Math.cos(this.angle * Math.PI / 180) / this.scaleMax) * this.length;
        this.yPos = this.yBase - (r * Math.sin(this.angle * Math.PI / 180) / this.scaleMax) * this.length;
    },
    
    lissajous: function(angle, f1, f2) {
        var r = f1 + f2;
        this.xPos = this.xBase + (f1 / this.scaleMax) * this.length;
        this.yPos = this.yBase - (f2 / this.scaleMax) * this.length;
    }
};
